# Dialog弹出框

## 介绍

弹出模态框，常用于消息提示、消息确认，或在当前页面内完成特定的交互操作。

## 效果图

![效果图](https://img.tanjiu.cn/home/XZ8tX2yiBE5xmxw5QGEy6Nb2QYZ4wcEz.png)

## 引入

在app.json或页面配置json中引入

```json
"usingComponents": {
    "xt-dialog": "@xtdev/xt-miniprogram-ui/xt-dialog",
}
```

## 代码演示

### 1 纯文本样式

<img src="https://img.tanjiu.cn/home/PWGNtJ6hkZebE48ZACEsPHkcesfxSKEj.png" alt="纯文本样式" style="zoom: 50%;" />

#### 1）单项操作

```html
<xt-dialog show="{{true}}" type="nomal" message="内容内容内容" confirmButtonText="我知道了" bind:confirm="onConfirm"></xt-dialog>
```

#### 2）双向操作

```html
<xt-dialog show="{{true}}" type="nomal" message="内容内容内容" confirmButtonText="确定" showCancelButton="{{true}}" cancelButtonText="取消" bind:confirm="onConfirm" bind:cancel="onCancel"></xt-dialog>
```

### 2 标题样式

<img src="https://img.tanjiu.cn/home/22paHdnC7hPhTEBRRT7pfdkGECybNFzD.png" alt="标题样式" style="zoom:50%;" />

#### 1）单项操作

```html
<xt-dialog show="{{true}}" type="nomal" title="标题标题标题" message="内容内容内容" confirmButtonText="我知道了" bind:confirm="onConfirm"></xt-dialog>
```

#### 2）双向操作

```html
<xt-dialog show="{{true}}" type="nomal" title="标题标题标题" message="内容内容内容" confirmButtonText="确定" showCancelButton="{{true}}" cancelButtonText="取消" bind:confirm="onConfirm" bind:cancel="onCancel"></xt-dialog>
```

### 3 图文样式

<img src="https://img.tanjiu.cn/home/5xpzpCFA62TFn5DWjFQK4GmyiBbxEGiC.png" alt="图文样式" style="zoom: 80%;" />

#### 1）单项操作

```html
<xt-dialog type="imageText" show="{{true}}" title="标题标题标题" message="内容内容内容内容内容" imageUrl="https://img.tanjiu.cn/home/CdrcxcSwjinKwJwaSadAzMYpnZtTj4WK.webp" confirmButtonText="我知道了" showCancelButton="{{false}}" bind:confirm="onImgTextConfirm"></xt-dialog>
```

#### 2）双项操作

```html
<xt-dialog type="imageText" show="{{true}}" title="标题标题标题" message="内容内容内容内容内容" imageUrl="https://img.tanjiu.cn/home/CdrcxcSwjinKwJwaSadAzMYpnZtTj4WK.webp" confirmButtonText="确定" showCancelButton="{{true}}" cancelButtonText="取消" bind:confirm="onImgTextConfirm" bind:cancel="onImgTextCancel"></xt-dialog>
```

### 4 输入样式

<img src="https://img.tanjiu.cn/home/X2bAjz2FQc6mNewfhbNBQfHm6zTmfYzd.png" alt="输入样式" style="zoom:50%;" />

```html
<xt-dialog type="inputText" show="{{showInputDialog}}" title="标题标题标题" message="" placeholder="请输入内容" confirmButtonText="确定" showCancelButton="{{true}}" cancelButtonText="取消" bind:confirm="onInputConfirm" bind:cancel="onInputCancel"></xt-dialog>
```

### 5 选择器样式

<img src="https://img.tanjiu.cn/home/yKrCY5MnGFS3FcjJ6pJRz5fXmJEHrSay.png" alt="选择器样式" style="zoom:50%;" />

```html
<xt-dialog type="choose" show="{{true}}" title="标题标题标题" chooiceItems="{{chooiceItems}}" confirmButtonText="确定" showCancelButton="{{true}}" cancelButtonText="取消" bind:confirm="onChooseConfirm" bind:cancel="onChooseCancel"></xt-dialog>
```

#### 1）常规情况下的 chooiceItems 参数

```json
chooiceItems:[
	{
    	value:0,
        label:'内容内容内容内容内容内容'
    },
    {
        value:1,
        label:'内容内容内容内容内容内容'
    }
]
```

#### 2）带辅助信息情况下的 chooiceItems 参数

```json
chooiceItems:[
	{
    	value:0,
        label:'内容内容内容内容内容内容',
        remark:'辅助信息辅助信息辅助信息'
    },
    {
        value:1,
        label:'内容内容内容内容内容内容',
        remark:'辅助信息辅助信息辅助信息'
    }
]
```

## API

### xt-dialog props

| 参数              | 说明                                                       | 类型    | 默认值     |
| ----------------- | ---------------------------------------------------------- | ------- | ---------- |
| show              | 是否显示                                                   | Boolean | true       |
| type              | 弹窗类型，可选值为`nomal` `imageText` `inputText` `choose` | String  | nomal      |
| title             | 标题                                                       | String  | null       |
| message           | 内容                                                       | String  | ''         |
| showConfirmButton | 是否展示确认按钮                                           | Boolean | true       |
| showCancelButton  | 是否展示取消按钮                                           | Boolean | false      |
| confirmButtonText | 确认按钮的文案                                             | String  | 确认       |
| cancelButtonText  | 取消按钮的文案                                             | String  | 取消       |
| placeholder       | 输入框占位符，仅当type为'inputText'时有用                  | String  | 请输入内容 |
| imageUrl          | 图片链接，仅当type为'imageText'时有用                      | String  | null       |
| chooiceItems      | 选项内容，仅当type为'choose'时有用                         | Array   | null       |

### chooiceItems props []

| 参数   | 说明           | 类型                    |
| ------ | -------------- | ----------------------- |
| value  | 选项的value值  | Number\|String\|Boolean |
| label  | 选项的文本描述 | String                  |
| remark | 选项的辅助信息 | String                  |

### Events

| 事件         | 说明               | 回调参数     |
| ------------ | ------------------ | ------------ |
| bind:confirm | 点击确认按钮时触发 | event.detail |
| bind:ccancel | 点击取消按钮时触发 | -            |







